Like label_topics() but returns the values behind the ranking, not just
the words — e.g. the numeric FREX score per top term (stm issue #265).
Usage
topic_terms(
model,
n = 7L,
by = c("prob", "frex", "lift", "score"),
frexweight = 0.5
)Like label_topics() but returns the values behind the ranking, not just
the words — e.g. the numeric FREX score per top term (stm issue #265).
topic_terms(
model,
n = 7L,
by = c("prob", "frex", "lift", "score"),
frexweight = 0.5
)